@@ -388,11 +388,19 @@ func TestCmd_Route(t *testing.T) {
 		{"push", []string{"push", "current"}},
 		{"reset", []string{"reset"}},
 		{"clean", []string{"clean", "files"}},
-		{"complete", []string{"complete", "bash"}},
-		{"fetch", []string{"fetch", "--prune"}},
+		{"version", []string{"version"}},
+		{"clean-interactive", []string{"clean-interactive"}},
 		{"remote", []string{"remote", "list"}},
 		{"rebase", []string{"rebase", "interactive"}},
-		{"stash", []string{"stash", "trash"}},
+		{"stash", []string{"stash", "drop"}},
+		{"config", []string{"config", "list"}},
+		{"hook", []string{"hook", "list"}},
+		{"tag", []string{"tag", "list"}},
+		{"status", []string{"status"}},
+		{"complete", []string{"complete", "bash"}},
+		{"fetch", []string{"fetch", "--prune"}},
+		{"diff", []string{"diff"}},
+		{"restore", []string{"restore", "."}},
 		{"unknown", []string{"unknown"}},
 	}
 
